@@ -122,7 +122,7 @@ def run_app(project=None, default_config_path=None, default_settings=None,
     if default_settings:
         settings_mod = import_module(default_settings)
         # TODO: logan should create a proxy module for its settings
-        management.setup_environ(settings_mod)
+        management.setup_environ(settings_mod, default_settings)
         add_settings(settings_mod)
 
     load_settings(config_path)
